pub struct ScriptMiddleware { /* private fields */ }Expand description
A script-based middleware.
Can modify requests before handlers and responses after handlers.
Implementations
Sourceimpl ScriptMiddleware
impl ScriptMiddleware
Sourcepub fn before(engine: Arc<RhaiEngine>, script_path: impl Into<PathBuf>) -> Self
pub fn before(engine: Arc<RhaiEngine>, script_path: impl Into<PathBuf>) -> Self
Create a new middleware with before script.
Sourcepub fn after(engine: Arc<RhaiEngine>, script_path: impl Into<PathBuf>) -> Self
pub fn after(engine: Arc<RhaiEngine>, script_path: impl Into<PathBuf>) -> Self
Create a new middleware with after script.
Sourcepub fn both(
engine: Arc<RhaiEngine>,
before: impl Into<PathBuf>,
after: impl Into<PathBuf>,
) -> Self
pub fn both( engine: Arc<RhaiEngine>, before: impl Into<PathBuf>, after: impl Into<PathBuf>, ) -> Self
Create a new middleware with both before and after scripts.
Sourcepub async fn call_before(
&self,
request: &HttpRequest,
) -> Result<Option<HttpResponse>>
pub async fn call_before( &self, request: &HttpRequest, ) -> Result<Option<HttpResponse>>
Execute the before script.
Returns Some(response) if the middleware wants to short-circuit,
or None to continue to the handler.
Sourcepub async fn call_after(
&self,
request: &HttpRequest,
response: HttpResponse,
) -> Result<HttpResponse>
pub async fn call_after( &self, request: &HttpRequest, response: HttpResponse, ) -> Result<HttpResponse>
Execute the after script.